@@ -2,7 +2,6 @@ import os
 import unittest
 import sys
 
-from flaky import flaky
 import pytest
 
 from qtpy import QtCore, QtGui, QtWidgets
@@ -34,7 +33,6 @@ def qtconsole(qtbot):
     console.window.close()
 
 
-@flaky(max_runs=3)
 @pytest.mark.parametrize(
     "debug", [True, False])
 def test_scroll(qtconsole, qtbot, debug):
@@ -141,7 +139,6 @@ def test_scroll(qtconsole, qtbot, debug):
     assert scroll_bar.value() > prev_position
 
 
-@flaky(max_runs=3)
 def test_input(qtconsole, qtbot):
     """
     Test input function
@@ -174,7 +171,6 @@ def test_input(qtconsole, qtbot):
     assert 'name: test\ntest' in control.toPlainText()
 
 
-@flaky(max_runs=3)
 def test_debug(qtconsole, qtbot):
     """
     Make sure the cursor works while debugging
@@ -208,7 +204,6 @@ def test_debug(qtconsole, qtbot):
     assert control.toPlainText().strip().split()[-1] == "abcd"
 
 
-@flaky(max_runs=15)
 def test_input_and_print(qtconsole, qtbot):
     """
     Test that we print correctly mixed input and print statements.
@@ -260,7 +255,6 @@ while user_input != '':
     assert output in control.toPlainText()
 
 
-@flaky(max_runs=5)
 @pytest.mark.skipif(os.name == 'nt', reason="no SIGTERM on Windows")
 def test_restart_after_kill(qtconsole, qtbot):
     """
